# Welcome to Toytree!


<!-- Welcome to <span style="color:rgba(20%,65%,65%)">**Toytree**</span> a minimalist tree manipulation and plotting library for Python based on <span style="color:rgba(98%,55%,38%)">**Toyplot**</span> ([http://toyplot.readthedocs.io](http://toyplot.rtfd.io)).  -->
Welcome to **Toytree** a minimalist tree manipulation and plotting library for Python based on **Toyplot** ([http://toyplot.readthedocs.io](http://toyplot.rtfd.io)). 
After reading the documentation if you have further questions about usage or want to contribute to the Toytree code please join the discussion on [gitter.im/toytree-help](https://gitter.im/toytree-help/Lobby), and if you have feature requests or bugs to report raise a ticket on [the github repo.](http://github.com/eaton-lab/toytree)


## The Toytree ethos

**Toytree** is intended to provide a Python equivalent to the popular tree plotting package **ape** in R. Following the design ethos of Toyplot, **Toytree** aims to be
rich in features but simple in design, with the following aesthetic goals:

<p></p>
+ <span style="text-decoration:underline;">Simplicity</span>: Toytree provides beautiful "out-of-the-box” figures that look good with minimal styling, but offers a wide-variety of styling options through simple CSS semantics. 

<p></p>
+ <span style="text-decoration:underline;">Transparency</span>: Tree objects are represented with a simple hierarchical structure that is easy to traverse, modify, and annotate. Interactive plotting makes it easy to visualize tree meta-data and 
explore results. 

<!-- You can access and download the raw data (newick file) from a Toytree HTML figure by simply clicking on the file and selecting download. -->

<p></p>
+ <span style="text-decoration:underline;">Reproducibility</span>: Toytree plots can be embedded directly in jupyter notebooks, a tool used for reproducible science, 
along with the code used to produce them. Toytree plots can be easily combined 
with barplots and scatterplots using Toyplot. 

<!-- 
## Jupyter notebooks
If you are not familiar with jupyter-notebooks the best way to get started is to give one a try. You can try out Toytree without having to install anything by clicking the binder link below which will start up a jupyter-notebook running in the cloud with Toytree installed (it may take a minute to load): [![Binder](http://mybinder.org/badge.svg)](http://mybinder.org:/repo/eaton-lab/toytree) 


## Example gallery

... -->